import os.path
from pathlib import Path
import click
from datetime import datetime
import pickle
from jinja2 import Environment, PackageLoader, select_autoescape

dir_home_user = os.path.abspath(Path.home())
dir_AzatAI = os.path.join(dir_home_user, '.AzatAI')
dir_pkg = os.path.join(dir_AzatAI, 'startpkg')
path_config = os.path.join(dir_pkg, 'config.azt')


env = Environment(
    loader=PackageLoader('src', 'templates'),
)


dir_root = Path(os.path.abspath(os.path.dirname(__file__))).parent


def prepare_path_n_files():
    os.system('mkdir -p ~/.AzatAI/startpkg')


def check_file_exist(file):
    if os.path.isfile(file):
        return True
    else:
        return False


def check_dir_exist(dir):
    if os.path.isdir(dir):
        return True
    else:
        return False



def write_configure(pkg_dir,configure_object):
    with open('__version__.py','w') as f:
        f.write(configure_object)

def configure(verbose, create_data):
    config_data = {}
    if verbose:
        update_config()
    while (not check_file_exist(path_config)):
        update_config()
    with open(path_config, 'rb') as f:
        stored = pickle.load(f)

    config_data['author'] = stored['author']
    config_data['author_email'] = stored['author_email']
    config_data['license'] = stored['license']
    config_data['copyright'] = stored['copyright']

    for param in create_data.keys():
        config_data[f'{param}'] = create_data[param]

    template_version = env.get_template('__version__.py')
    return template_version.render(config_data)
    

def update_config():
    prepare_path_n_files()
    os.system('mkdir -p ~/.AzatAI/startpkg')
    config = {}
    """ Update and save the default reuseable data to the ~/.AzatAI/config.azt
    This file can be loaded when creating the new package and been used.
    """
    this_year = datetime.now().year
    config['author'] = click.prompt(
        "Package Author:", default='Yaakov Azat', confirmation_prompt=True, show_default=True)
    config['author_email'] = click.prompt(
        "Package Author Email:", default='yaakovazat@gmail.com', show_default=True)
    config['license'] = click.prompt(
        "License:", default='MIT', show_default=True)
    config['copyright'] = click.prompt(
        "Copyright:", default=f'Copyright {this_year} Azat Artificial Intelligence, LLP (AzatAI)', show_default=True)

    with open(path_config, 'wb') as f:
        pickle.dump(config, f)



import os
from pathlib import Path
import pickle
import click
from .utils import check_file_exist, configure, write_configure

dir_home_user = os.path.abspath(Path.home())
dir_AzatAI = os.path.join(dir_home_user, '.AzatAI')
dir_pkg = os.path.join(dir_AzatAI, 'startpkg')
path_config = os.path.join(dir_pkg, 'config.azt')


@click.command()
@click.option('-v', '--verbose', help='Regenerate the copyright base(Author and email information for further packages.)', default=False, show_default=True)
def cli(verbose):
    """AzatAI Start Package Tool (startpkg) CLI"""
    click.secho(
        "Welcome to using the AzatAI Start Package Tool (startpkg)", fg='blue')
    create_data = {}
    click.secho('Input package information below:\n', fg='blue')
    create_data['pkg_name'] = click.prompt('Package Name:')
    create_data['pkg_description'] = click.prompt('Package Description:')
    create_data['pkg_url'] = click.prompt('Package URL:')
    create_data['pkg_version'] = click.prompt('Package Version(x.y.z):')

    here = os.path.abspath(os.path.dirname(__file__))
    pkg_path = os.path.join(here, create_data['pkg_name'])
    cmd_dir = f"mkdir ./{pkg_path}"
    pkg_content = [
        '__init__.py',
        '__cli.py__',
        'exceptions.py',
        'help.py',
        'models.py',
        'status_codes.py',
        'utils.py'
    ]
    for each in pkg_content:
        file_path = os.path.join(pkg_path, f'{each}')
        cmd_touch = f'touch {file_path}'
        os.system(cmd_touch)
    pkg_root = {
        'dirs':[
            'tests',
        ],
        'files':[
            'README.md',
            'LICENSE',
            'MANIFEST.in',
            '.travis.yml',
            'requirements.txt',
        ]
    }
    for each in pkg_root['files']:
        file_path = os.path.join(here, f'{each}')
        cmd_touch = f'touch {file_path}'
        os.system(cmd_touch)
    for each in pkg_root['dirs']:
        if not os.path.isdir(os.path.join(here,f'{each}')):
            os.makedirs(os.path.join(here, f'{each}'), exist_ok=True)
    rendered = configure(verbose, create_data)
    write_configure(pkg_path,rendered)




#!/usr/bin/env python3
#                            _                _____ 
#      /\                   | |       /\     |_   _|
#     /  \     ____   __ _  | |_     /  \      | |  
#    / /\ \   |_  /  / _` | | __|   / /\ \     | |  
#   / ____ \   / /  | (_| | | |_   / ____ \   _| |_ 
#  /_/    \_\ /___|  \__,_|  \__| /_/    \_\ |_____|
#                                         
#                        


__title__ = 'startpkg'
__description__ = 'AzatAI Start Package Tool (startpkg)'
__url__ = 'https://github.com/AzatAI/startpkg'
__version__ = '0.1.5'
__author__ = 'Yaakov Azat'
__author_email__ = 'yaakovazat@gmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2020 Azat Artificial Intelligence, LLP (AzatAI)'


#!/usr/bin/env python3

import os
import re
import sys

from codecs import open

from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))


# 'setup.py publish' shortcut.
if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist')
    os.system('twine upload dist/*')
    os.system('rm -rf dist')
    os.system('rm -rf *.egg-info')
    sys.exit()


requires = [
    'click',
    'twine',
    'jinja2'
]


about = {}  # create a empty dictionary to store the content of the __version__.py file
# execute the __version__.py file and get the content, save to the dictionary about.
with open(os.path.join(here, 'src', '__version__.py'), 'r', 'utf-8') as f:
    exec(f.read(), about)

with open('README.md', 'r', 'utf-8') as f:
    readme = f.read()

setup(
    name=about['__title__'],
    version=about['__version__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=find_packages(),
    package_data={'': ['LICENSE']},
    # package_dir={'startpkg': 'src'},
    include_package_data=True,
    python_requires=">=3.5",
    install_requires=requires,
    entry_points='''
        [console_scripts]
        startpkg=src.cli:cli
    ''',
    license=about['__license__'],
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    project_urls={
        'Documentation': 'https://azat.ai',
        'Source': 'https://github.com/AzatAI/startpkg',
    },
)
